@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-12 01:44:34 +0800 (Wed, 12 Jun 2019) $
+# $Date: 2019-06-12 01:44:34 +0800 (週三, 12 六月 2019) $
 # $Revision: 11629 $ 
 
 from django.conf.urls import url
+from django.urls import include, path
 
 from . import views
 
@@ -25,4 +26,5 @@ urlpatterns = [
     url(r'^comments/add$', views.CommentView.as_view(), name='addComment'),
     url(r'^comments/(?P<pk>\d+)/hide$', 
         views.CommentHideView.as_view(), name='hideComment'),
+    path('captcha/', include('captcha.urls')),        
 ]
